@@ -10,10 +10,9 @@ class VideoTestCase(unittest.TestCase):
         from kivy.uix.video import Video
         from kivy.clock import Clock
         from kivy.base import runTouchApp, stopTouchApp
+        from kivy import kivy_examples_dir
         from os.path import join, dirname, abspath
-        here = dirname(__file__)
-        source = abspath(join(
-            here, "..", "..", "examples", "widgets", "cityCC0.mpg"))
+        source = abspath(join(kivy_examples_dir, "widgets", "cityCC0.mpg"))
         video = Video(source=source, play=True)
         Clock.schedule_once(lambda x: stopTouchApp(), 1)
 
